@@ -88,13 +88,16 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
+import aws_cdk.aws_apigateway
 import aws_cdk.aws_cognito
 import aws_cdk.aws_dynamodb
+import aws_cdk.aws_iam
+import aws_cdk.aws_kinesis
 import aws_cdk.aws_kinesisfirehose
 import aws_cdk.aws_kms
 import aws_cdk.aws_lambda
@@ -103,6 +106,138 @@ import aws_cdk.aws_sns
 import aws_cdk.aws_sqs
 
 
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/core.AddProxyMethodToApiResourceInputParams",
+    jsii_struct_bases=[],
+    name_mapping={
+        "api_gateway_role": "apiGatewayRole",
+        "api_method": "apiMethod",
+        "api_resource": "apiResource",
+        "request_template": "requestTemplate",
+        "service": "service",
+        "action": "action",
+        "content_type": "contentType",
+        "path": "path",
+        "request_model": "requestModel",
+        "request_validator": "requestValidator",
+    },
+)
+class AddProxyMethodToApiResourceInputParams:
+    def __init__(
+        self,
+        *,
+        api_gateway_role: aws_cdk.aws_iam.Role,
+        api_method: builtins.str,
+        api_resource: aws_cdk.aws_apigateway.IResource,
+        request_template: builtins.str,
+        service: builtins.str,
+        action: typing.Optional[builtins.str] = None,
+        content_type: typing.Optional[builtins.str] = None,
+        path: typing.Optional[builtins.str] = None,
+        request_model: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_apigateway.IModel]] = None,
+        request_validator: typing.Optional[aws_cdk.aws_apigateway.RequestValidator] = None,
+    ) -> None:
+        """
+        :param api_gateway_role: -
+        :param api_method: -
+        :param api_resource: -
+        :param request_template: -
+        :param service: -
+        :param action: -
+        :param content_type: -
+        :param path: -
+        :param request_model: -
+        :param request_validator: -
+        """
+        self._values: typing.Dict[str, typing.Any] = {
+            "api_gateway_role": api_gateway_role,
+            "api_method": api_method,
+            "api_resource": api_resource,
+            "request_template": request_template,
+            "service": service,
+        }
+        if action is not None:
+            self._values["action"] = action
+        if content_type is not None:
+            self._values["content_type"] = content_type
+        if path is not None:
+            self._values["path"] = path
+        if request_model is not None:
+            self._values["request_model"] = request_model
+        if request_validator is not None:
+            self._values["request_validator"] = request_validator
+
+    @builtins.property
+    def api_gateway_role(self) -> aws_cdk.aws_iam.Role:
+        result = self._values.get("api_gateway_role")
+        assert result is not None, "Required property 'api_gateway_role' is missing"
+        return result
+
+    @builtins.property
+    def api_method(self) -> builtins.str:
+        result = self._values.get("api_method")
+        assert result is not None, "Required property 'api_method' is missing"
+        return result
+
+    @builtins.property
+    def api_resource(self) -> aws_cdk.aws_apigateway.IResource:
+        result = self._values.get("api_resource")
+        assert result is not None, "Required property 'api_resource' is missing"
+        return result
+
+    @builtins.property
+    def request_template(self) -> builtins.str:
+        result = self._values.get("request_template")
+        assert result is not None, "Required property 'request_template' is missing"
+        return result
+
+    @builtins.property
+    def service(self) -> builtins.str:
+        result = self._values.get("service")
+        assert result is not None, "Required property 'service' is missing"
+        return result
+
+    @builtins.property
+    def action(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("action")
+        return result
+
+    @builtins.property
+    def content_type(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("content_type")
+        return result
+
+    @builtins.property
+    def path(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("path")
+        return result
+
+    @builtins.property
+    def request_model(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_apigateway.IModel]]:
+        result = self._values.get("request_model")
+        return result
+
+    @builtins.property
+    def request_validator(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_apigateway.RequestValidator]:
+        result = self._values.get("request_validator")
+        return result
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "AddProxyMethodToApiResourceInputParams(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/core.BuildDeadLetterQueueProps",
     jsii_struct_bases=[],
@@ -122,7 +257,7 @@ class BuildDeadLetterQueueProps:
         :param dead_letter_queue: An existing queue that has already been defined to be used as the dead letter queue. Default: - Default props are used.
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Default: - Default props are used
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "dead_letter_queue": dead_letter_queue,
         }
         if max_receive_count is not None:
@@ -135,7 +270,9 @@ class BuildDeadLetterQueueProps:
         default
         :default: - Default props are used.
         """
-        return self._values.get("dead_letter_queue")
+        result = self._values.get("dead_letter_queue")
+        assert result is not None, "Required property 'dead_letter_queue' is missing"
+        return result
 
     @builtins.property
     def max_receive_count(self) -> typing.Optional[jsii.Number]:
@@ -144,12 +281,13 @@ class BuildDeadLetterQueueProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("max_receive_count")
+        result = self._values.get("max_receive_count")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -179,7 +317,7 @@ class BuildDynamoDBTableProps:
         """
         if isinstance(dynamo_table_props, dict):
             dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if dynamo_table_props is not None:
             self._values["dynamo_table_props"] = dynamo_table_props
         if existing_table_obj is not None:
@@ -192,7 +330,8 @@ class BuildDynamoDBTableProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("dynamo_table_props")
+        result = self._values.get("dynamo_table_props")
+        return result
 
     @builtins.property
     def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
@@ -203,12 +342,13 @@ class BuildDynamoDBTableProps:
         default
         :default: - None
         """
-        return self._values.get("existing_table_obj")
+        result = self._values.get("existing_table_obj")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -217,45 +357,6 @@ class BuildDynamoDBTableProps:
         )
 
 
-@jsii.data_type(
-    jsii_type="@aws-solutions-constructs/core.BuildEncryptionKeyProps",
-    jsii_struct_bases=[],
-    name_mapping={"encryption_key_props": "encryptionKeyProps"},
-)
-class BuildEncryptionKeyProps:
-    def __init__(
-        self, *, encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None
-    ) -> None:
-        """
-        :param encryption_key_props: Optional user-provided props to override the default props for the encryption key. Default: - Default props are used.
-        """
-        if isinstance(encryption_key_props, dict):
-            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
-        self._values = {}
-        if encryption_key_props is not None:
-            self._values["encryption_key_props"] = encryption_key_props
-
-    @builtins.property
-    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
-        """Optional user-provided props to override the default props for the encryption key.
-
-        default
-        :default: - Default props are used.
-        """
-        return self._values.get("encryption_key_props")
-
-    def __eq__(self, rhs) -> bool:
-        return isinstance(rhs, self.__class__) and rhs._values == self._values
-
-    def __ne__(self, rhs) -> bool:
-        return not (rhs == self)
-
-    def __repr__(self) -> str:
-        return "BuildEncryptionKeyProps(%s)" % ", ".join(
-            k + "=" + repr(v) for k, v in self._values.items()
-        )
-
-
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/core.BuildKinesisAnalyticsAppProps",
     jsii_struct_bases=[],
@@ -275,7 +376,7 @@ class BuildKinesisAnalyticsAppProps:
         :param kinesis_firehose: A Kinesis Data Firehose for the Kinesis Streams application to connect to. Default: - Default props are used
         :param kinesis_analytics_props: Optional user provided props to override the default props for the Kinesis analytics app. Default: - Default props are used
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "kinesis_firehose": kinesis_firehose,
         }
         if kinesis_analytics_props is not None:
@@ -288,7 +389,9 @@ class BuildKinesisAnalyticsAppProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("kinesis_firehose")
+        result = self._values.get("kinesis_firehose")
+        assert result is not None, "Required property 'kinesis_firehose' is missing"
+        return result
 
     @builtins.property
     def kinesis_analytics_props(self) -> typing.Any:
@@ -297,12 +400,13 @@ class BuildKinesisAnalyticsAppProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("kinesis_analytics_props")
+        result = self._values.get("kinesis_analytics_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -314,17 +418,38 @@ class BuildKinesisAnalyticsAppProps:
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/core.BuildKinesisStreamProps",
     jsii_struct_bases=[],
-    name_mapping={"kinesis_stream_props": "kinesisStreamProps"},
+    name_mapping={
+        "existing_stream_obj": "existingStreamObj",
+        "kinesis_stream_props": "kinesisStreamProps",
+    },
 )
 class BuildKinesisStreamProps:
-    def __init__(self, *, kinesis_stream_props: typing.Any = None) -> None:
+    def __init__(
+        self,
+        *,
+        existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+        kinesis_stream_props: typing.Any = None,
+    ) -> None:
         """
+        :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
         :param kinesis_stream_props: Optional user provided props to override the default props for the Kinesis stream. Default: - Default props are used.
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
+        if existing_stream_obj is not None:
+            self._values["existing_stream_obj"] = existing_stream_obj
         if kinesis_stream_props is not None:
             self._values["kinesis_stream_props"] = kinesis_stream_props
 
+    @builtins.property
+    def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
+        """Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
+
+        default
+        :default: - None
+        """
+        result = self._values.get("existing_stream_obj")
+        return result
+
     @builtins.property
     def kinesis_stream_props(self) -> typing.Any:
         """Optional user provided props to override the default props for the Kinesis stream.
@@ -332,12 +457,13 @@ class BuildKinesisStreamProps:
         default
         :default: - Default props are used.
         """
-        return self._values.get("kinesis_stream_props")
+        result = self._values.get("kinesis_stream_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -366,10 +492,8 @@ class BuildLambdaFunctionProps:
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
         """
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **lambda_function_props
-            )
-        self._values = {}
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        self._values: typing.Dict[str, typing.Any] = {}
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
         if lambda_function_props is not None:
@@ -382,7 +506,8 @@ class BuildLambdaFunctionProps:
         default
         :default: - None
         """
-        return self._values.get("existing_lambda_obj")
+        result = self._values.get("existing_lambda_obj")
+        return result
 
     @builtins.property
     def lambda_function_props(
@@ -393,12 +518,13 @@ class BuildLambdaFunctionProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("lambda_function_props")
+        result = self._values.get("lambda_function_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -412,6 +538,9 @@ class BuildLambdaFunctionProps:
     jsii_struct_bases=[],
     name_mapping={
         "dead_letter_queue": "deadLetterQueue",
+        "enable_encryption_with_customer_managed_key": "enableEncryptionWithCustomerManagedKey",
+        "encryption_key": "encryptionKey",
+        "encryption_key_props": "encryptionKeyProps",
         "existing_queue_obj": "existingQueueObj",
         "queue_props": "queueProps",
     },
@@ -421,21 +550,35 @@ class BuildQueueProps:
         self,
         *,
         dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue] = None,
+        enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
         """
         :param dead_letter_queue: Optional dead letter queue to pass bad requests to after the max receive count is reached. Default: - Default props are used.
+        :param enable_encryption_with_customer_managed_key: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - false (encryption enabled with AWS Managed KMS Key).
+        :param encryption_key: An optional, imported encryption key to encrypt the SQS queue with. Default: - not specified.
+        :param encryption_key_props: Optional user-provided props to override the default props for the encryption key. Default: - Ignored if encryptionKey is provided
         :param existing_queue_obj: Existing instance of SQS queue object, if this is set then the queueProps is ignored. Default: - None.
         :param queue_props: Optional user provided props to override the default props for the primary queue. Default: - Default props are used.
         """
         if isinstance(dead_letter_queue, dict):
             dead_letter_queue = aws_cdk.aws_sqs.DeadLetterQueue(**dead_letter_queue)
+        if isinstance(encryption_key_props, dict):
+            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
+        if enable_encryption_with_customer_managed_key is not None:
+            self._values["enable_encryption_with_customer_managed_key"] = enable_encryption_with_customer_managed_key
+        if encryption_key is not None:
+            self._values["encryption_key"] = encryption_key
+        if encryption_key_props is not None:
+            self._values["encryption_key_props"] = encryption_key_props
         if existing_queue_obj is not None:
             self._values["existing_queue_obj"] = existing_queue_obj
         if queue_props is not None:
@@ -448,7 +591,43 @@ class BuildQueueProps:
         default
         :default: - Default props are used.
         """
-        return self._values.get("dead_letter_queue")
+        result = self._values.get("dead_letter_queue")
+        return result
+
+    @builtins.property
+    def enable_encryption_with_customer_managed_key(
+        self,
+    ) -> typing.Optional[builtins.bool]:
+        """Use a KMS Key, either managed by this CDK app, or imported.
+
+        If importing an encryption key, it must be specified in
+        the encryptionKey property for this construct.
+
+        default
+        :default: - false (encryption enabled with AWS Managed KMS Key).
+        """
+        result = self._values.get("enable_encryption_with_customer_managed_key")
+        return result
+
+    @builtins.property
+    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
+        """An optional, imported encryption key to encrypt the SQS queue with.
+
+        default
+        :default: - not specified.
+        """
+        result = self._values.get("encryption_key")
+        return result
+
+    @builtins.property
+    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
+        """Optional user-provided props to override the default props for the encryption key.
+
+        default
+        :default: - Ignored if encryptionKey is provided
+        """
+        result = self._values.get("encryption_key_props")
+        return result
 
     @builtins.property
     def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
@@ -457,7 +636,8 @@ class BuildQueueProps:
         default
         :default: - None.
         """
-        return self._values.get("existing_queue_obj")
+        result = self._values.get("existing_queue_obj")
+        return result
 
     @builtins.property
     def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
@@ -466,12 +646,13 @@ class BuildQueueProps:
         default
         :default: - Default props are used.
         """
-        return self._values.get("queue_props")
+        result = self._values.get("queue_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -483,29 +664,22 @@ class BuildQueueProps:
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/core.BuildS3BucketProps",
     jsii_struct_bases=[],
-    name_mapping={
-        "bucket_props": "bucketProps",
-        "existing_bucket_obj": "existingBucketObj",
-    },
+    name_mapping={"bucket_props": "bucketProps"},
 )
 class BuildS3BucketProps:
     def __init__(
         self,
         *,
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
     ) -> None:
         """
         :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
-        :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
         """
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
-        if existing_bucket_obj is not None:
-            self._values["existing_bucket_obj"] = existing_bucket_obj
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
@@ -514,21 +688,13 @@ class BuildS3BucketProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("bucket_props")
+        result = self._values.get("bucket_props")
+        return result
 
-    @builtins.property
-    def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        """Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
-
-        default
-        :default: - None
-        """
-        return self._values.get("existing_bucket_obj")
-
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -541,8 +707,10 @@ class BuildS3BucketProps:
     jsii_type="@aws-solutions-constructs/core.BuildTopicProps",
     jsii_struct_bases=[],
     name_mapping={
-        "enable_encryption": "enableEncryption",
+        "enable_encryption_with_customer_managed_key": "enableEncryptionWithCustomerManagedKey",
         "encryption_key": "encryptionKey",
+        "encryption_key_props": "encryptionKeyProps",
+        "existing_topic_obj": "existingTopicObj",
         "topic_props": "topicProps",
     },
 )
@@ -550,36 +718,49 @@ class BuildTopicProps:
     def __init__(
         self,
         *,
-        enable_encryption: typing.Optional[bool] = None,
+        enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None,
+        existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
         topic_props: typing.Optional[aws_cdk.aws_sns.TopicProps] = None,
     ) -> None:
         """
-        :param enable_encryption: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - true (encryption enabled, managed by this CDK app).
+        :param enable_encryption_with_customer_managed_key: Use a Customer Managed KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - false (encryption enabled with AWS Managed KMS Key).
         :param encryption_key: An optional, imported encryption key to encrypt the SNS topic with. Default: - not specified.
+        :param encryption_key_props: Optional user-provided props to override the default props for the encryption key. Default: - Ignored if encryptionKey is provided
+        :param existing_topic_obj: Existing instance of SNS Topic object, if this is set then the TopicProps is ignored. Default: - None.
         :param topic_props: Optional user provided props to override the default props for the SNS topic. Default: - Default props are used.
         """
+        if isinstance(encryption_key_props, dict):
+            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
         if isinstance(topic_props, dict):
             topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
-        self._values = {}
-        if enable_encryption is not None:
-            self._values["enable_encryption"] = enable_encryption
+        self._values: typing.Dict[str, typing.Any] = {}
+        if enable_encryption_with_customer_managed_key is not None:
+            self._values["enable_encryption_with_customer_managed_key"] = enable_encryption_with_customer_managed_key
         if encryption_key is not None:
             self._values["encryption_key"] = encryption_key
+        if encryption_key_props is not None:
+            self._values["encryption_key_props"] = encryption_key_props
+        if existing_topic_obj is not None:
+            self._values["existing_topic_obj"] = existing_topic_obj
         if topic_props is not None:
             self._values["topic_props"] = topic_props
 
     @builtins.property
-    def enable_encryption(self) -> typing.Optional[bool]:
-        """Use a KMS Key, either managed by this CDK app, or imported.
+    def enable_encryption_with_customer_managed_key(
+        self,
+    ) -> typing.Optional[builtins.bool]:
+        """Use a Customer Managed KMS Key, either managed by this CDK app, or imported.
 
         If importing an encryption key, it must be specified in
         the encryptionKey property for this construct.
 
         default
-        :default: - true (encryption enabled, managed by this CDK app).
+        :default: - false (encryption enabled with AWS Managed KMS Key).
         """
-        return self._values.get("enable_encryption")
+        result = self._values.get("enable_encryption_with_customer_managed_key")
+        return result
 
     @builtins.property
     def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
@@ -588,7 +769,28 @@ class BuildTopicProps:
         default
         :default: - not specified.
         """
-        return self._values.get("encryption_key")
+        result = self._values.get("encryption_key")
+        return result
+
+    @builtins.property
+    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
+        """Optional user-provided props to override the default props for the encryption key.
+
+        default
+        :default: - Ignored if encryptionKey is provided
+        """
+        result = self._values.get("encryption_key_props")
+        return result
+
+    @builtins.property
+    def existing_topic_obj(self) -> typing.Optional[aws_cdk.aws_sns.Topic]:
+        """Existing instance of SNS Topic object, if this is set then the TopicProps is ignored.
+
+        default
+        :default: - None.
+        """
+        result = self._values.get("existing_topic_obj")
+        return result
 
     @builtins.property
     def topic_props(self) -> typing.Optional[aws_cdk.aws_sns.TopicProps]:
@@ -597,12 +799,13 @@ class BuildTopicProps:
         default
         :default: - Default props are used.
         """
-        return self._values.get("topic_props")
+        result = self._values.get("topic_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -625,10 +828,10 @@ class CfnDomainOptions:
     def __init__(
         self,
         *,
-        cognito_authorized_role_arn: str,
+        cognito_authorized_role_arn: builtins.str,
         identitypool: aws_cdk.aws_cognito.CfnIdentityPool,
         userpool: aws_cdk.aws_cognito.UserPool,
-        service_role_arn: typing.Optional[str] = None,
+        service_role_arn: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param cognito_authorized_role_arn: -
@@ -636,7 +839,7 @@ class CfnDomainOptions:
         :param userpool: -
         :param service_role_arn: -
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "cognito_authorized_role_arn": cognito_authorized_role_arn,
             "identitypool": identitypool,
             "userpool": userpool,
@@ -645,25 +848,32 @@ class CfnDomainOptions:
             self._values["service_role_arn"] = service_role_arn
 
     @builtins.property
-    def cognito_authorized_role_arn(self) -> str:
-        return self._values.get("cognito_authorized_role_arn")
+    def cognito_authorized_role_arn(self) -> builtins.str:
+        result = self._values.get("cognito_authorized_role_arn")
+        assert result is not None, "Required property 'cognito_authorized_role_arn' is missing"
+        return result
 
     @builtins.property
     def identitypool(self) -> aws_cdk.aws_cognito.CfnIdentityPool:
-        return self._values.get("identitypool")
+        result = self._values.get("identitypool")
+        assert result is not None, "Required property 'identitypool' is missing"
+        return result
 
     @builtins.property
     def userpool(self) -> aws_cdk.aws_cognito.UserPool:
-        return self._values.get("userpool")
+        result = self._values.get("userpool")
+        assert result is not None, "Required property 'userpool' is missing"
+        return result
 
     @builtins.property
-    def service_role_arn(self) -> typing.Optional[str]:
-        return self._values.get("service_role_arn")
+    def service_role_arn(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("service_role_arn")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -694,7 +904,7 @@ class CognitoOptions:
         :param userpool: -
         :param userpoolclient: -
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "identitypool": identitypool,
             "userpool": userpool,
             "userpoolclient": userpoolclient,
@@ -702,20 +912,26 @@ class CognitoOptions:
 
     @builtins.property
     def identitypool(self) -> aws_cdk.aws_cognito.CfnIdentityPool:
-        return self._values.get("identitypool")
+        result = self._values.get("identitypool")
+        assert result is not None, "Required property 'identitypool' is missing"
+        return result
 
     @builtins.property
     def userpool(self) -> aws_cdk.aws_cognito.UserPool:
-        return self._values.get("userpool")
+        result = self._values.get("userpool")
+        assert result is not None, "Required property 'userpool' is missing"
+        return result
 
     @builtins.property
     def userpoolclient(self) -> aws_cdk.aws_cognito.UserPoolClient:
-        return self._values.get("userpoolclient")
+        result = self._values.get("userpoolclient")
+        assert result is not None, "Required property 'userpoolclient' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -725,9 +941,9 @@ class CognitoOptions:
 
 
 __all__ = [
+    "AddProxyMethodToApiResourceInputParams",
     "BuildDeadLetterQueueProps",
     "BuildDynamoDBTableProps",
-    "BuildEncryptionKeyProps",
     "BuildKinesisAnalyticsAppProps",
     "BuildKinesisStreamProps",
     "BuildLambdaFunctionProps",
